/*
 $Id$
*/
#ifndef _GRID_H_
#define _GRID_H_
/* grid.h
   author - Eric Bylaska
*/

extern	void	init_Grids(int);
extern	void	end_Grids();
extern	double	*alloc_Grid();
extern	void	dealloc_Grid(double*);

#endif
